==> luckperms-api-4.1-sources.jar: me/lucko/luckperms/api/NodeEqualityPredicate.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package me.lucko.luckperms.api;

import javax.annotation.Nonnull;

/**
 * A rule for determining if two nodes are equal.
 *
 * <p>Generally, individual instances of this interface should fulfil the same
 * requirements as the {@link Object#equals(Object)} contract.</p>
 *
 * <p>Some standard implementations are provided by
 * {@link StandardNodeEquality}.</p>
 *
 * @since 4.1
 */
@FunctionalInterface
public interface NodeEqualityPredicate {

    /**
     * Returns if the two nodes are equal
     *
     * @param o1 the first node
     * @param o2 the second node
     * @return true if equal
     */
    boolean areEqual(@Nonnull Node o1, @Nonnull Node o2);

}

==> luckperms-api-4.3-sources.jar: me/lucko/luckperms/api/NodeEqualityPredicate.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package me.lucko.luckperms.api;

import org.checkerframework.checker.nullness.qual.NonNull;

/**
 * A rule for determining if two nodes are equal.
 *
 * <p>Generally, individual instances of this interface should fulfil the same
 * requirements as the {@link Object#equals(Object)} contract.</p>
 *
 * <p>Some standard implementations are provided by {@link StandardNodeEquality}.</p>
 *
 * @since 4.1
 */
@FunctionalInterface
public interface NodeEqualityPredicate {

    /**
     * Returns if the two nodes are equal
     *
     * @param o1 the first node
     * @param o2 the second node
     * @return true if equal
     */
    boolean areEqual(@NonNull Node o1, @NonNull Node o2);

}
